The purpose of ecoreSync is the replication and caching of remotely hosted model contents using the Essential Object Query (EOQ) language (https://gitlab.com/eoq). These model contents are represented using the JavaScript ECORE meta-model implementation ecore.js (https://emfjson.github.io/ecore.js/). EcoreSync aids in the reduction of necessary remote queries and, therefore, accelerates application relying on remote model contents. Applications are fully relieved of the management of remote objects. EcoreSync automatically resolves queries from its cache and only makes queries to the remote host when necessary. Changes to queries can be easily observed through the EcoreSync observer functionalities.
